@@ -25,7 +25,10 @@ use vars qw( %map_aliases );
 		'latex'   => 'LaTeX',
 		'texinfo' => 'Texinfo',
 		'text'    => 'Text',
+		'wiki'    => 'Wiki',
 		'textov'  => 'TextOV',
+		'xml'	=> 'XML',
+		'sgml'	=> 'SGML',
 		);
 
 ## ----------------------------------------------------------------------
